RXUtils class

Constructors

RXUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

paddingAll(BuildContext context, double value) EdgeInsets
paddingSymmetric(BuildContext context, double horizontal, double vertical) EdgeInsets
responsiveButton(BuildContext context, {required Widget child, required VoidCallback onTap, double height = 48, double horizontalPadding = 16}) Widget
roundedBox(BuildContext context, {double radius = 12, Color? color}) BoxDecoration