ResponsiveBreakpoints class

Constructors

ResponsiveBreakpoints({required double mobile, required double tablet, required double desktop, required double largeDesktop})
const

Properties

desktop double
final
hashCode int
The hash code for this object.
no setterinherited
largeDesktop double
final
mobile double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tablet double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited