ResponsiveX class

Constructors

ResponsiveX()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

scale(BuildContext context, double base) double

Constants

desktopScale → const double
largeDesktopScale → const double
mobileScale → const double
tabletScale → const double